function Lh  = DiscreteLaplaceMatrix_FivePointStar(n)
% Returns the discrete Laplace operator with the 5-Point Stencil scheme for
% the unit square and lexicographic ordering of the nodes

% Compute the corresponding h
h = 1/n;

% Compute the discrete Laplace operator
%

% main diagonal
L = spdiags(4* ones((n-1)^2,1) , 0, (n-1)^2, (n-1)^2);

% minor diagonals
v = repmat( [ones(n-2,1); 0], n-1, 1);
v = v(1:end-1);
L = L - spdiags( v, -1, (n-1)^2, (n-1)^2);
v = [0; v];
L = L - spdiags( v, 1, (n-1)^2, (n-1)^2);

% further minor diagonals
v = ones((n-1)^2,1);
L = L - spdiags( v, -n+1, (n-1)^2, (n-1)^2);
L = L - spdiags( v, n-1, (n-1)^2, (n-1)^2);

% Scaling with -1/h^2
Lh = -1/h^2 * L;

% easier:
I = speye(n-1);
T = spdiags(2*ones(n-1),0,n-1,n-1) - spdiags(ones(n-1),-1,n-1,n-1) -spdiags(ones(n-1),1,n-1,n-1);
Lh = -1/h^2 * ( kron(I, T) + kron(T,I) );
